@@ -1,6 +1,6 @@
 package Catalyst::Controller::Combine;
 BEGIN {
-  $Catalyst::Controller::Combine::VERSION = '0.12';
+  $Catalyst::Controller::Combine::VERSION = '0.13';
 }
 
 use Moose;
@@ -15,27 +15,39 @@ use Text::Glob qw(match_glob);
 has dir       => (is => 'rw',
                   default => sub { 'static/' . shift->action_namespace },
                   lazy => 1);
+
 has extension => (is => 'rw',
                   default => sub { shift->action_namespace },
                   lazy => 1);
+
 has depend    => (is => 'rw',
                   default => sub { return {} });
+
 has mimetype  => (is => 'rw',
                   default => sub {
                                     my $ext = shift->extension;
-
                                     return $ext eq 'js'  ? 'application/javascript'
                                          : $ext eq 'css' ? 'text/css'
                                          : 'text/plain';
                                  },
                   lazy => 1);
+
 has replace   => (is => 'rw',
                   default => sub { {} },
-                  lazy => 1);
+                  lazy => 1,
+                  predicate => 'has_replacement');
+
+has include   => (is => 'rw',
+                  default => sub { [] },
+                  lazy => 1,
+                  predicate => 'has_include');
+
 has minifier  => (is => 'rw',
                   default => 'minify');
+
 has expire    => (is => 'rw',
                   default => 0);
+
 has expire_in => (is => 'rw',
                   default => 60 * 60 * 24 * 365 * 3); # 3 years
 
@@ -46,7 +58,7 @@ Catalyst::Controller::Combine - Combine JS/CSS Files
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -65,7 +77,6 @@ version 0.12
     # will deliver all CSS files concatenated (in Css-Controller)
     <link rel="stylesheet" type="text/css" href="/css/file1/file2/.../filex.css" />
 
-
     # in the generated controller you may add this to allow minification
     # the trick behind is the existence of a sub named 'minify'
     # inside your Controller.
@@ -160,29 +171,6 @@ TODO: writeme...
 
 =head1 METHODS
 
-=head2 BUILD
-
-constructor for this Moose-driven class
-
-=cut
-
-sub BUILD {
-    my $self = shift;
-    my $c = $self->_app;
-
-    ### THIS STUPID BLOCK BREAKS TESTS UNDER DIFFERENT C::MOP / MOOSE VERSIONS...
-    ### $self->dir wants to know action_namespace...
-    # $c->log->warn(ref($self) . " - directory '" . $self->dir . "' not present.")
-    #     if (!-d $c->path_to('root', $self->dir));
-    #
-    # $c->log->debug(ref($self) . " - " .
-    #                "directory: '" . $self->dir . "', " .
-    #                "extension: '" . $self->extension . "', " .
-    #                "mimetype: '" . $self->mimetype . "', " .
-    #                "minifier: '" . $self->minifier . "'")
-    #     if ($c->debug);
-}
-
 =head2 do_combine :Action
 
 the C<do_combine> Action-method may be used like this (eg in YourApp:Controller:Js):
@@ -211,6 +199,9 @@ Thus, inside your Controller a simple
 
 will do the job and auto-minify the stream.
 
+If you specify an C<include> configuration option you also could recursively
+include other files into the generated stream. (Think about @import in css files).
+
 =cut
 
 sub do_combine :Action {
@@ -224,49 +215,57 @@ sub do_combine :Action {
     #
     my $mtime = 0;
     my $response = '';
-    foreach my $file_path (@{$self->{files}}) {
-        if (open(my $file, '<', $file_path)) {
-            local $/ = undef;
-            my $file_content = <$file>;
-
-            # do replacements if wanted
-            if (exists($self->{replacement_for}->{$file_path})) {
-                my @replacement = (
-                    # poor man's deep-copy
-                    @{$self->{replacement_for}->{$file_path}}
-                );
-                while (my ($regex, $replace) = splice(@replacement,0,2)) {
-                    $file_content =~ s{$regex}{qq{qq{$replace}}}gmsee;
-                }
+    foreach my $file (@{$self->{files}}) {
+        my $file_content = $self->_file_contents($file, \$mtime);
+        
+        if (exists($self->{replacement_for}->{$file})) {
+            my @replacement = (
+                # poor man's deep-copy, splice below is destructive
+                @{$self->{replacement_for}->{$file}}
+            );
+            while (my ($regex, $replace) = splice(@replacement,0,2)) {
+                $file_content =~ s{$regex}{qq{qq{$replace}}}gmsee;
             }
-
-            # append to output stream
-            $response .= $file_content;
-            close($file);
-            $mtime = max($mtime, (stat $file_path)->mtime);
         }
-        # silently ignore any errors that might occur
+        
+        $response .= $file_content;
     }
 
-    die 'no files given for combining' if (!$mtime);
+    die 'no files given for combining' if !$mtime;
 
     #
     # deliver -- at least an empty line to make catalyst happy ;-)
     #
     my $minifier = $self->can($self->minifier)
-        || sub { $_[0] }; # simple identity function
+        || \&_do_not_modify;
     $c->response->headers->content_type($self->mimetype)
-        if ($self->mimetype);
+        if $self->mimetype;
     $c->response->headers->last_modified($mtime)
-        if ($mtime);
-
-    if ($self->{expire} && $self->{expire_in}) {
-        $c->response->headers->expires(time() + $self->{expire_in});
-    }
+        if $mtime;
+    $c->response->headers->expires(time() + $self->expire_in)
+        if $self->expire && $self->expire_in;
 
     $c->response->body($minifier->($response) . "\n");
 }
 
+sub _do_not_modify { $_[0] };
+
+sub _file_contents {
+    my $self = shift;
+    my $file = shift;
+    my $mtime_ref = shift;
+    
+    my $file_contents = $file->slurp;
+    $$mtime_ref = max($$mtime_ref, (stat $file)->mtime);
+    
+    if ($self->has_include) {
+        $file_contents =~ s{$_}{ $self->_file_contents($file->dir->file($1), $mtime_ref) }exmsg
+            for @{$self->include}
+    }
+    
+    return $file_contents;
+}
+
 =head2 default :Path
 
 a standard handler for your application's controller
